# @jupyterlab/coreutils

A JupyterLab package which provides utility functions that are widely used
across many of the `@jupyterlab` packages. This includes (among other things)
functions for manipulating paths, urls, and the notebook format.

This package is intended for use within both Node.js and browser environments.
